<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$pageTitle = "Editar Crédito";
$creditId = isset($_GET['id']) ? (int)$_GET['id'] : null;

if (!$creditId) {
    header('Location: index.php');
    exit;
}

try {
    $db = Database::getInstance()->getConnection();

    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $db->beginTransaction();

        // Validar y sanitizar datos
        $customerName = sanitize($_POST['customer_name']);
        $customerContact = sanitize($_POST['customer_contact']);
        $totalAmount = filter_var($_POST['total_amount'], FILTER_VALIDATE_FLOAT);
        $numInstallments = filter_var($_POST['num_installments'], FILTER_VALIDATE_INT);
        $startDate = $_POST['start_date'];
        $outstandingBalance = filter_var($_POST['outstanding_balance'], FILTER_VALIDATE_FLOAT);

        $errors = [];
        if (empty($customerName)) {
            $errors[] = "El nombre del cliente es requerido.";
        }
        if (!$totalAmount || $totalAmount <= 0) {
            $errors[] = "El monto total debe ser mayor a 0.";
        }
        if (!in_array($numInstallments, INSTALLMENT_OPTIONS)) {
            $errors[] = "El número de cuotas no es válido.";
        }
        if (!strtotime($startDate)) {
            $errors[] = "La fecha de inicio no es válida.";
        }
        if (!$outstandingBalance && $outstandingBalance !== 0.0) {
            $errors[] = "El saldo pendiente no es válido.";
        }

        if (empty($errors)) {
            // Obtener datos actuales del crédito
            $stmt = $db->prepare("
                SELECT c.*, cu.id as customer_id 
                FROM credits c 
                JOIN customers cu ON c.customer_id = cu.id 
                WHERE c.id = ?
            ");
            $stmt->execute([$creditId]);
            $currentCredit = $stmt->fetch();

            if (!$currentCredit) {
                throw new Exception("Crédito no encontrado");
            }

            // Actualizar datos del cliente
            $stmt = $db->prepare("UPDATE customers SET name = ?, contact = ? WHERE id = ?");
            $stmt->execute([$customerName, $customerContact, $currentCredit['customer_id']]);

            // Actualizar crédito
            $stmt = $db->prepare("
                UPDATE credits 
                SET total_amount = ?,
                    num_installments = ?,
                    start_date = ?,
                    outstanding_balance = ?,
                    updated_at = CURRENT_TIMESTAMP
                WHERE id = ?
            ");
            $stmt->execute([
                $totalAmount,
                $numInstallments,
                $startDate,
                $outstandingBalance,
                $creditId
            ]);

            $db->commit();
            $_SESSION['success_message'] = "Crédito actualizado exitosamente.";
            header('Location: index.php');
            exit;
        }
        
        if (!empty($errors)) {
            $db->rollBack();
        }
    }

    // Obtener datos actuales del crédito
    $stmt = $db->prepare("
        SELECT 
            c.*,
            cu.name as customer_name,
            cu.contact as customer_contact,
            (SELECT COUNT(*) FROM payments p WHERE p.credit_id = c.id) as payments_made
        FROM credits c
        JOIN customers cu ON c.customer_id = cu.id
        WHERE c.id = ?
    ");
    $stmt->execute([$creditId]);
    $credit = $stmt->fetch();

    if (!$credit) {
        throw new Exception("Crédito no encontrado");
    }

    require_once 'templates/header.php';
?>

<div class="bg-white rounded-lg shadow-md p-6 max-w-2xl mx-auto">
    <div class="flex items-center justify-between mb-6">
        <h1 class="text-2xl font-semibold text-gray-800">
            <i class="fas fa-edit mr-2"></i>Editar Crédito
        </h1>
        <a href="index.php" class="text-blue-500 hover:text-blue-600">
            <i class="fas fa-arrow-left mr-1"></i>Volver
        </a>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
            <p class="font-bold">Por favor corrija los siguientes errores:</p>
            <ul class="list-disc list-inside">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <form action="edit_credit.php?id=<?php echo $creditId; ?>" method="POST" class="space-y-6" data-validate>
        <!-- Datos del Cliente -->
        <div class="bg-gray-50 p-4 rounded-lg">
            <h2 class="text-lg font-medium text-gray-800 mb-4">Datos del Cliente</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <label for="customer_name" class="block text-sm font-medium text-gray-700 mb-1">
                        Nombre del Cliente <span class="text-red-500">*</span>
                    </label>
                    <input type="text" 
                           id="customer_name" 
                           name="customer_name" 
                           required
                           value="<?php echo htmlspecialchars($credit['customer_name']); ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
                <div>
                    <label for="customer_contact" class="block text-sm font-medium text-gray-700 mb-1">
                        Contacto
                    </label>
                    <input type="text" 
                           id="customer_contact" 
                           name="customer_contact"
                           value="<?php echo htmlspecialchars($credit['customer_contact']); ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
            </div>
        </div>

        <!-- Datos del Crédito -->
        <div class="bg-gray-50 p-4 rounded-lg">
            <h2 class="text-lg font-medium text-gray-800 mb-4">Datos del Crédito</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <label for="total_amount" class="block text-sm font-medium text-gray-700 mb-1">
                        Monto Total <span class="text-red-500">*</span>
                    </label>
                    <div class="relative">
                        <span class="absolute inset-y-0 left-0 pl-3 flex items-center text-gray-500">$</span>
                        <input type="number" 
                               id="total_amount" 
                               name="total_amount" 
                               required
                               step="0.01"
                               min="0"
                               value="<?php echo $credit['total_amount']; ?>"
                               class="w-full pl-8 rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                    </div>
                </div>
                <div>
                    <label for="num_installments" class="block text-sm font-medium text-gray-700 mb-1">
                        Número de Cuotas <span class="text-red-500">*</span>
                    </label>
                    <select id="num_installments" 
                            name="num_installments" 
                            required
                            class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                        <?php foreach (INSTALLMENT_OPTIONS as $option): ?>
                            <option value="<?php echo $option; ?>" 
                                    <?php echo ($credit['num_installments'] == $option) ? 'selected' : ''; ?>>
                                <?php echo $option; ?> cuotas
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div>
                    <label for="start_date" class="block text-sm font-medium text-gray-700 mb-1">
                        Fecha de Inicio <span class="text-red-500">*</span>
                    </label>
                    <input type="date" 
                           id="start_date" 
                           name="start_date" 
                           required
                           value="<?php echo $credit['start_date']; ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
                <div>
                    <label for="outstanding_balance" class="block text-sm font-medium text-gray-700 mb-1">
                        Saldo Pendiente <span class="text-red-500">*</span>
                    </label>
                    <div class="relative">
                        <span class="absolute inset-y-0 left-0 pl-3 flex items-center text-gray-500">$</span>
                        <input type="number" 
                               id="outstanding_balance" 
                               name="outstanding_balance" 
                               required
                               step="0.01"
                               min="0"
                               value="<?php echo $credit['outstanding_balance']; ?>"
                               class="w-full pl-8 rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                    </div>
                </div>
            </div>
        </div>

        <!-- Información Adicional -->
        <div class="bg-blue-50 p-4 rounded-lg">
            <h2 class="text-lg font-medium text-blue-800 mb-4">Información Adicional</h2>
            <div class="grid grid-cols-2 gap-4">
                <div>
                    <p class="text-sm text-blue-600">Cuotas Pagadas:</p>
                    <p class="font-medium"><?php echo $credit['payments_made']; ?> de <?php echo $credit['num_installments']; ?></p>
                </div>
                <div>
                    <p class="text-sm text-blue-600">Fecha de Creación:</p>
                    <p class="font-medium"><?php echo formatDate($credit['created_at']); ?></p>
                </div>
            </div>
        </div>

        <div class="flex justify-end space-x-2">
            <a href="index.php" 
               class="px-4 py-2 border border-gray-300 rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                Cancelar
            </a>
            <button type="submit" 
                    class="px-4 py-2 border border-transparent rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                <i class="fas fa-save mr-1"></i> Guardar Cambios
            </button>
        </div>
    </form>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const totalAmountInput = document.getElementById('total_amount');
    const numInstallmentsSelect = document.getElementById('num_installments');
    const outstandingBalanceInput = document.getElementById('outstanding_balance');
    
    function validateOutstandingBalance() {
        const totalAmount = parseFloat(totalAmountInput.value) || 0;
        const outstandingBalance = parseFloat(outstandingBalanceInput.value) || 0;
        
        if (outstandingBalance > totalAmount) {
            outstandingBalanceInput.setCustomValidity('El saldo pendiente no puede ser mayor al monto total');
        } else {
            outstandingBalanceInput.setCustomValidity('');
        }
    }
    
    totalAmountInput.addEventListener('input', validateOutstandingBalance);
    outstandingBalanceInput.addEventListener('input', validateOutstandingBalance);
});
</script>

<?php
    require_once 'templates/footer.php';
} catch (Exception $e) {
    error_log("Error en edit_credit.php: " . $e->getMessage());
    $errorMessage = "Ha ocurrido un error al cargar el crédito. Por favor, intente nuevamente.";
    require_once 'templates/header.php';
    echo "<div class='bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4' role='alert'>
            <p class='font-bold'>Error</p>
            <p>$errorMessage</p>
          </div>";
    require_once 'templates/footer.php';
}
?>