<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$paymentId = isset($_GET['payment_id']) ? (int)$_GET['payment_id'] : null;

if (!$paymentId) {
    header('Location: index.php');
    exit;
}

try {
    $db = Database::getInstance()->getConnection();
    
    // Obtener información del pago y crédito
    $stmt = $db->prepare("
        SELECT 
            p.id as payment_id,
            p.payment_date,
            p.payment_amount,
            p.installment_number,
            c.id as credit_id,
            c.total_amount,
            c.num_installments,
            c.outstanding_balance,
            cu.name as customer_name,
            cu.contact as customer_contact
        FROM payments p
        JOIN credits c ON p.credit_id = c.id
        JOIN customers cu ON c.customer_id = cu.id
        WHERE p.id = ?
    ");
    
    $stmt->execute([$paymentId]);
    $payment = $stmt->fetch();
    
    if (!$payment) {
        throw new Exception("Pago no encontrado");
    }

    // Calcular información adicional
    $installmentAmount = $payment['total_amount'] / $payment['num_installments'];
    $remainingInstallments = $payment['num_installments'] - $payment['installment_number'];
    
    // Generar HTML del recibo
    ?>
    <!DOCTYPE html>
    <html lang="es">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Recibo de Pago - <?php echo COMPANY_NAME; ?></title>
        <script src="https://cdn.tailwindcss.com"></script>
        <style>
            @media print {
                .no-print {
                    display: none;
                }
                body {
                    padding: 20px;
                }
                .receipt {
                    border: none !important;
                    box-shadow: none !important;
                }
            }
        </style>
    </head>
    <body class="bg-gray-100 min-h-screen p-4">
        <div class="max-w-2xl mx-auto">
            <!-- Botones de acción -->
            <div class="mb-4 flex justify-between no-print">
                <a href="index.php" class="bg-blue-500 text-white px-4 py-2 rounded hover:bg-blue-600">
                    <i class="fas fa-arrow-left mr-1"></i> Volver
                </a>
                <button onclick="window.print()" class="bg-green-500 text-white px-4 py-2 rounded hover:bg-green-600">
                    <i class="fas fa-print mr-1"></i> Imprimir
                </button>
            </div>

            <!-- Recibo -->
            <div class="bg-white p-8 rounded-lg shadow-lg receipt">
                <!-- Encabezado -->
                <div class="text-center mb-8">
                    <img src="<?php echo LOGO_URL; ?>" alt="Logo" class="mx-auto mb-4 h-20">
                    <h1 class="text-4xl font-bold text-gray-800 mb-2">RECIBO</h1>
                    <p class="text-xl text-gray-600"><?php echo COMPANY_NAME; ?></p>
                </div>

                <!-- Información del recibo -->
                <div class="mb-8">
                    <div class="grid grid-cols-2 gap-4">
                        <div>
                            <p class="text-gray-600">Recibo N°:</p>
                            <p class="font-bold"><?php echo str_pad($payment['payment_id'], 8, '0', STR_PAD_LEFT); ?></p>
                        </div>
                        <div>
                            <p class="text-gray-600">Fecha:</p>
                            <p class="font-bold"><?php echo formatDate($payment['payment_date']); ?></p>
                        </div>
                    </div>
                </div>

                <!-- Información del cliente -->
                <div class="mb-8">
                    <h2 class="text-lg font-semibold mb-2 text-gray-800">Datos del Cliente</h2>
                    <div class="bg-gray-50 p-4 rounded">
                        <p><span class="text-gray-600">Nombre:</span> 
                           <span class="font-bold"><?php echo htmlspecialchars($payment['customer_name']); ?></span></p>
                        <?php if ($payment['customer_contact']): ?>
                            <p><span class="text-gray-600">Contacto:</span> 
                               <span class="font-bold"><?php echo htmlspecialchars($payment['customer_contact']); ?></span></p>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Detalles del pago -->
                <div class="mb-8">
                    <h2 class="text-lg font-semibold mb-2 text-gray-800">Detalles del Pago</h2>
                    <div class="bg-gray-50 p-4 rounded">
                        <table class="w-full">
                            <tr>
                                <td class="py-2 text-gray-600">Cuota N°:</td>
                                <td class="py-2 font-bold text-right">
                                    <?php echo $payment['installment_number']; ?> de <?php echo $payment['num_installments']; ?>
                                </td>
                            </tr>
                            <tr>
                                <td class="py-2 text-gray-600">Monto de Cuota:</td>
                                <td class="py-2 font-bold text-right"><?php echo formatMoney($installmentAmount); ?></td>
                            </tr>
                            <tr>
                                <td class="py-2 text-gray-600">Monto Pagado:</td>
                                <td class="py-2 font-bold text-right"><?php echo formatMoney($payment['payment_amount']); ?></td>
                            </tr>
                            <tr class="border-t border-gray-200">
                                <td class="py-2 text-gray-600">Saldo Pendiente:</td>
                                <td class="py-2 font-bold text-right"><?php echo formatMoney($payment['outstanding_balance']); ?></td>
                            </tr>
                        </table>
                    </div>
                </div>

                <!-- Firma -->
                <div class="mt-12 pt-8 border-t border-gray-200">
                    <div class="flex justify-between">
                        <div class="text-center">
                            <div class="border-t border-gray-400 w-48 mx-auto mt-16"></div>
                            <p class="text-gray-600 mt-2">Firma del Cliente</p>
                        </div>
                        <div class="text-center">
                            <div class="border-t border-gray-400 w-48 mx-auto mt-16"></div>
                            <p class="text-gray-600 mt-2">Firma Autorizada</p>
                        </div>
                    </div>
                </div>

                <!-- Pie de página -->
                <div class="mt-8 pt-8 border-t border-gray-200 text-center text-gray-500 text-sm">
                    <p>Este recibo es válido como comprobante de pago.</p>
                    <p class="mt-2">¡Gracias por su pago!</p>
                </div>
            </div>
        </div>
    </body>
    </html>
    <?php
} catch (Exception $e) {
    error_log("Error generando recibo: " . $e->getMessage());
    header('Location: index.php');
    exit;
}
?>