<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$pageTitle = "Importar Datos";
$results = [];

try {
    $db = Database::getInstance()->getConnection();

    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['csv_file'])) {
        $file = $_FILES['csv_file'];
        $allowedTypes = ['text/csv', 'application/vnd.ms-excel'];
        
        $errors = [];
        
        // Validar archivo
        if ($file['error'] !== UPLOAD_ERR_OK) {
            $errors[] = "Error al subir el archivo.";
        } elseif (!in_array($file['type'], $allowedTypes)) {
            $errors[] = "El archivo debe ser un CSV válido.";
        }

        if (empty($errors)) {
            $db->beginTransaction();
            
            try {
                if (($handle = fopen($file['tmp_name'], "r")) !== FALSE) {
                    // Saltar la primera línea (encabezados)
                    $headers = fgetcsv($handle);
                    
                    $results = [
                        'processed' => 0,
                        'success' => 0,
                        'errors' => 0,
                        'messages' => []
                    ];

                    while (($data = fgetcsv($handle)) !== FALSE) {
                        $results['processed']++;
                        
                        try {
                            // Validar datos mínimos requeridos
                            if (count($data) < 3) {
                                throw new Exception("Faltan campos requeridos en la línea " . $results['processed']);
                            }

                            // Extraer datos
                            $customerName = sanitize($data[1]);
                            $contact = sanitize($data[2]);
                            $totalAmount = filter_var($data[3], FILTER_VALIDATE_FLOAT);
                            $numInstallments = filter_var($data[4], FILTER_VALIDATE_INT);
                            $outstandingBalance = filter_var($data[6], FILTER_VALIDATE_FLOAT);
                            $startDate = $data[7];

                            // Validaciones
                            if (empty($customerName)) {
                                throw new Exception("Nombre de cliente vacío en la línea " . $results['processed']);
                            }
                            if (!$totalAmount || $totalAmount <= 0) {
                                throw new Exception("Monto total inválido en la línea " . $results['processed']);
                            }
                            if (!in_array($numInstallments, INSTALLMENT_OPTIONS)) {
                                throw new Exception("Número de cuotas inválido en la línea " . $results['processed']);
                            }
                            if (!strtotime($startDate)) {
                                throw new Exception("Fecha de inicio inválida en la línea " . $results['processed']);
                            }

                            // Verificar/Crear cliente
                            $stmt = $db->prepare("SELECT id FROM customers WHERE name = ?");
                            $stmt->execute([$customerName]);
                            $customer = $stmt->fetch();

                            if ($customer) {
                                $customerId = $customer['id'];
                                // Actualizar contacto si es diferente
                                $stmt = $db->prepare("UPDATE customers SET contact = ? WHERE id = ?");
                                $stmt->execute([$contact, $customerId]);
                            } else {
                                $stmt = $db->prepare("INSERT INTO customers (name, contact) VALUES (?, ?)");
                                $stmt->execute([$customerName, $contact]);
                                $customerId = $db->lastInsertId();
                            }

                            // Insertar crédito
                            $stmt = $db->prepare("
                                INSERT INTO credits 
                                (customer_id, total_amount, num_installments, outstanding_balance, start_date) 
                                VALUES (?, ?, ?, ?, ?)
                            ");
                            $stmt->execute([
                                $customerId,
                                $totalAmount,
                                $numInstallments,
                                $outstandingBalance,
                                $startDate
                            ]);

                            $results['success']++;

                        } catch (Exception $e) {
                            $results['errors']++;
                            $results['messages'][] = $e->getMessage();
                        }
                    }
                    
                    fclose($handle);
                    
                    if ($results['errors'] == 0) {
                        $db->commit();
                        $successMessage = "Importación completada exitosamente. {$results['success']} registros importados.";
                    } else {
                        $db->rollBack();
                        $errorMessage = "Se encontraron errores durante la importación.";
                    }
                }
            } catch (Exception $e) {
                $db->rollBack();
                $errors[] = "Error procesando el archivo: " . $e->getMessage();
            }
        }
    }

    require_once 'templates/header.php';
?>

<div class="bg-white rounded-lg shadow-md p-6 max-w-2xl mx-auto">
    <div class="flex items-center justify-between mb-6">
        <h1 class="text-2xl font-semibold text-gray-800">
            <i class="fas fa-file-import mr-2"></i>Importar Datos
        </h1>
        <a href="index.php" class="text-blue-500 hover:text-blue-600">
            <i class="fas fa-arrow-left mr-1"></i>Volver
        </a>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-6" role="alert">
            <p class="font-bold">Se encontraron errores:</p>
            <ul class="list-disc list-inside">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <?php if (!empty($successMessage)): ?>
        <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-6" role="alert">
            <p class="font-bold">Éxito</p>
            <p><?php echo $successMessage; ?></p>
        </div>
    <?php endif; ?>

    <?php if (!empty($results) && !empty($results['messages'])): ?>
        <div class="bg-yellow-100 border-l-4 border-yellow-500 text-yellow-700 p-4 mb-6">
            <p class="font-bold">Resumen de la importación:</p>
            <ul class="list-none mt-2">
                <li>Registros procesados: <?php echo $results['processed']; ?></li>
                <li>Importados exitosamente: <?php echo $results['success']; ?></li>
                <li>Errores encontrados: <?php echo $results['errors']; ?></li>
            </ul>
            <?php if (!empty($results['messages'])): ?>
                <p class="font-bold mt-4">Detalles de los errores:</p>
                <ul class="list-disc list-inside mt-2">
                    <?php foreach ($results['messages'] as $message): ?>
                        <li><?php echo htmlspecialchars($message); ?></li>
                    <?php endforeach; ?>
                </ul>
            <?php endif; ?>
        </div>
    <?php endif; ?>

    <div class="bg-blue-50 p-6 rounded-lg mb-6">
        <h2 class="text-lg font-medium text-blue-800 mb-4">
            <i class="fas fa-info-circle mr-2"></i>Instrucciones
        </h2>
        <div class="space-y-4 text-blue-700">
            <p>El archivo CSV debe contener las siguientes columnas en orden:</p>
            <ol class="list-decimal list-inside ml-4 space-y-2">
                <li>ID (puede estar vacío para nuevos registros)</li>
                <li>Nombre del Cliente (requerido)</li>
                <li>Contacto</li>
                <li>Monto Total (requerido)</li>
                <li>Número de Cuotas (requerido: 4, 8, 12 o 16)</li>
                <li>Cuotas Pagadas</li>
                <li>Saldo Pendiente (requerido)</li>
                <li>Fecha de Inicio (requerido, formato YYYY-MM-DD)</li>
                <li>Estado</li>
                <li>Última Actualización</li>
            </ol>
            <p class="mt-4">
                Puede descargar una plantilla de ejemplo usando la función de exportación.
            </p>
        </div>
    </div>

    <form action="import.php" 
          method="POST" 
          enctype="multipart/form-data" 
          class="space-y-6">
        
        <div class="bg-gray-50 p-6 rounded-lg">
            <div class="space-y-4">
                <div>
                    <label for="csv_file" class="block text-sm font-medium text-gray-700 mb-2">
                        Seleccionar Archivo CSV
                    </label>
                    <input type="file" 
                           id="csv_file" 
                           name="csv_file" 
                           accept=".csv,text/csv,application/vnd.ms-excel"
                           required
                           class="block w-full text-sm text-gray-500
                                  file:mr-4 file:py-2 file:px-4
                                  file:rounded-full file:border-0
                                  file:text-sm file:font-semibold
                                  file:bg-blue-50 file:text-blue-700
                                  hover:file:bg-blue-100">
                </div>
                
                <div class="flex items-center">
                    <input type="checkbox" 
                           id="skip_errors" 
                           name="skip_errors" 
                           class="h-4 w-4 text-blue-600 focus:ring-blue-500 border-gray-300 rounded">
                    <label for="skip_errors" class="ml-2 block text-sm text-gray-900">
                        Continuar importación si se encuentran errores
                    </label>
                </div>
            </div>
        </div>

        <div class="flex justify-end space-x-2">
            <a href="index.php" 
               class="px-4 py-2 border border-gray-300 rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                Cancelar
            </a>
            <button type="submit" 
                    class="px-4 py-2 border border-transparent rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                <i class="fas fa-upload mr-1"></i> Importar Datos
            </button>
        </div>
    </form>

    <div class="mt-8 p-4 bg-yellow-50 rounded-lg">
        <div class="flex">
            <div class="flex-shrink-0">
                <i class="fas fa-exclamation-triangle text-yellow-400"></i>
            </div>
            <div class="ml-3">
                <h3 class="text-sm font-medium text-yellow-800">Importante</h3>
                <div class="mt-2 text-sm text-yellow-700">
                    <ul class="list-disc list-inside space-y-1">
                        <li>Asegúrese de que el archivo CSV esté correctamente formateado.</li>
                        <li>Se recomienda hacer una copia de seguridad antes de importar datos.</li>
                        <li>Los registros existentes se actualizarán si coinciden los IDs.</li>
                        <li>El proceso puede tardar dependiendo del tamaño del archivo.</li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
</div>

<?php
    require_once 'templates/footer.php';
} catch (Exception $e) {
    error_log("Error en import.php: " . $e->getMessage());
    $errorMessage = "Ha ocurrido un error al procesar la solicitud. Por favor, intente nuevamente.";
    require_once 'templates/header.php';
    echo "<div class='bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4' role='alert'>
            <p class='font-bold'>Error</p>
            <p>$errorMessage</p>
          </div>";
    require_once 'templates/footer.php';
}
?>