<?php
require_once 'config.php';
require_once 'db.php';

try {
    $db = Database::getInstance()->getConnection();
    
    // Comenzar transacción
    $db->beginTransaction();
    
    // Crear tabla de clientes
    $db->exec("
        CREATE TABLE IF NOT EXISTS customers (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(100) NOT NULL,
            contact VARCHAR(100),
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
    ");
    
    // Crear tabla de créditos
    $db->exec("
        CREATE TABLE IF NOT EXISTS credits (
            id INT AUTO_INCREMENT PRIMARY KEY,
            customer_id INT NOT NULL,
            total_amount DECIMAL(10,2) NOT NULL,
            num_installments INT NOT NULL,
            start_date DATE NOT NULL,
            outstanding_balance DECIMAL(10,2) NOT NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            FOREIGN KEY (customer_id) REFERENCES customers(id) ON DELETE RESTRICT,
            CHECK (num_installments IN (4,8,12,16))
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
    ");
    
    // Crear tabla de pagos
    $db->exec("
        CREATE TABLE IF NOT EXISTS payments (
            id INT AUTO_INCREMENT PRIMARY KEY,
            credit_id INT NOT NULL,
            payment_date DATE NOT NULL,
            payment_amount DECIMAL(10,2) NOT NULL,
            installment_number INT NOT NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (credit_id) REFERENCES credits(id) ON DELETE RESTRICT
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
    ");
    
    // Crear índices para mejorar el rendimiento
    $db->exec("CREATE INDEX idx_customer_name ON customers(name);");
    $db->exec("CREATE INDEX idx_credit_date ON credits(start_date);");
    $db->exec("CREATE INDEX idx_payment_date ON payments(payment_date);");
    
    // Confirmar transacción
    $db->commit();
    
    echo '<!DOCTYPE html>
    <html lang="es">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Instalación Completada - Sistema de Créditos</title>
        <script src="https://cdn.tailwindcss.com"></script>
    </head>
    <body class="bg-gray-100 min-h-screen flex items-center justify-center">
        <div class="bg-white p-8 rounded-lg shadow-md max-w-md w-full">
            <div class="text-center mb-6">
                <h1 class="text-2xl font-bold text-green-600 mb-2">¡Instalación Exitosa!</h1>
                <p class="text-gray-600">Las tablas de la base de datos han sido creadas correctamente.</p>
            </div>
            <div class="space-y-4">
                <div class="bg-green-50 p-4 rounded">
                    <h2 class="font-semibold text-green-800">Tablas creadas:</h2>
                    <ul class="list-disc list-inside text-green-700 mt-2">
                        <li>Clientes (customers)</li>
                        <li>Créditos (credits)</li>
                        <li>Pagos (payments)</li>
                    </ul>
                </div>
                <div class="bg-blue-50 p-4 rounded">
                    <h2 class="font-semibold text-blue-800">Próximos pasos:</h2>
                    <ol class="list-decimal list-inside text-blue-700 mt-2">
                        <li>Eliminar el archivo install.php por seguridad</li>
                        <li>Comenzar a usar el sistema accediendo a index.php</li>
                    </ol>
                </div>
                <div class="mt-6 text-center">
                    <a href="index.php" class="inline-block bg-blue-600 text-white px-6 py-2 rounded hover:bg-blue-700 transition-colors">
                        Ir al Sistema
                    </a>
                </div>
            </div>
        </div>
    </body>
    </html>';
    
} catch (PDOException $e) {
    // Revertir transacción en caso de error
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    
    echo '<!DOCTYPE html>
    <html lang="es">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Error de Instalación - Sistema de Créditos</title>
        <script src="https://cdn.tailwindcss.com"></script>
    </head>
    <body class="bg-gray-100 min-h-screen flex items-center justify-center">
        <div class="bg-white p-8 rounded-lg shadow-md max-w-md w-full">
            <div class="text-center mb-6">
                <h1 class="text-2xl font-bold text-red-600 mb-2">Error en la Instalación</h1>
                <p class="text-gray-600">Ocurrió un error durante la creación de las tablas.</p>
            </div>
            <div class="bg-red-50 p-4 rounded">
                <h2 class="font-semibold text-red-800">Detalles del error:</h2>
                <p class="text-red-700 mt-2">' . htmlspecialchars($e->getMessage()) . '</p>
            </div>
            <div class="mt-6 text-center">
                <p class="text-gray-600 mb-4">Por favor, verifique los datos de conexión y los permisos de la base de datos.</p>
                <button onclick="location.reload()" class="bg-blue-600 text-white px-6 py-2 rounded hover:bg-blue-700 transition-colors">
                    Intentar Nuevamente
                </button>
            </div>
        </div>
    </body>
    </html>';
    
    // Registrar el error
    error_log("Error de instalación: " . $e->getMessage());
}
?>