<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$pageTitle = "Registrar Pago";
$creditId = isset($_GET['credit_id']) ? (int)$_GET['credit_id'] : null;

try {
    $db = Database::getInstance()->getConnection();

    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $db->beginTransaction();

        // Validar y sanitizar datos
        $creditId = filter_var($_POST['credit_id'], FILTER_VALIDATE_INT);
        $paymentAmount = filter_var($_POST['payment_amount'], FILTER_VALIDATE_FLOAT);
        $paymentDate = $_POST['payment_date'];
        $installmentNumber = filter_var($_POST['installment_number'], FILTER_VALIDATE_INT);

        $errors = [];
        if (!$creditId) {
            $errors[] = "Crédito no válido.";
        }
        if (!$paymentAmount || $paymentAmount <= 0) {
            $errors[] = "El monto del pago debe ser mayor a 0.";
        }
        if (!strtotime($paymentDate)) {
            $errors[] = "La fecha de pago no es válida.";
        }
        if (!$installmentNumber || $installmentNumber <= 0) {
            $errors[] = "El número de cuota no es válido.";
        }

        if (empty($errors)) {
            // Verificar saldo pendiente
            $stmt = $db->prepare("SELECT outstanding_balance FROM credits WHERE id = ?");
            $stmt->execute([$creditId]);
            $credit = $stmt->fetch();

            if ($paymentAmount > $credit['outstanding_balance']) {
                $errors[] = "El monto del pago no puede ser mayor al saldo pendiente.";
            } else {
                // Registrar el pago
                $stmt = $db->prepare("
                    INSERT INTO payments 
                    (credit_id, payment_date, payment_amount, installment_number) 
                    VALUES (?, ?, ?, ?)
                ");
                $stmt->execute([$creditId, $paymentDate, $paymentAmount, $installmentNumber]);
                $paymentId = $db->lastInsertId();

                // Actualizar saldo pendiente
                $newBalance = $credit['outstanding_balance'] - $paymentAmount;
                $stmt = $db->prepare("
                    UPDATE credits 
                    SET outstanding_balance = ? 
                    WHERE id = ?
                ");
                $stmt->execute([$newBalance, $creditId]);

                $db->commit();
                
                // Redirigir a la página del recibo
                header("Location: generate_receipt.php?payment_id=" . $paymentId);
                exit;
            }
        }
        if (!empty($errors)) {
            $db->rollBack();
        }
    }

    // Obtener lista de créditos activos para el selector
    $stmt = $db->prepare("
        SELECT 
            c.id,
            c.total_amount,
            c.num_installments,
            c.outstanding_balance,
            cu.name as customer_name,
            (SELECT COUNT(*) FROM payments p WHERE p.credit_id = c.id) as payments_made
        FROM credits c
        JOIN customers cu ON c.customer_id = cu.id
        WHERE c.outstanding_balance > 0
        ORDER BY c.id DESC
    ");
    $stmt->execute();
    $credits = $stmt->fetchAll();

    // Si se proporciona un ID de crédito, obtener sus detalles
    $selectedCredit = null;
    if ($creditId) {
        foreach ($credits as $credit) {
            if ($credit['id'] == $creditId) {
                $selectedCredit = $credit;
                break;
            }
        }
    }

    require_once 'templates/header.php';
?>

<div class="bg-white rounded-lg shadow-md p-6 max-w-2xl mx-auto">
    <div class="flex items-center justify-between mb-6">
        <h1 class="text-2xl font-semibold text-gray-800">
            <i class="fas fa-cash-register mr-2"></i>Registrar Pago
        </h1>
        <a href="index.php" class="text-blue-500 hover:text-blue-600">
            <i class="fas fa-arrow-left mr-1"></i>Volver
        </a>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
            <p class="font-bold">Por favor corrija los siguientes errores:</p>
            <ul class="list-disc list-inside">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <form action="register_payment.php" method="POST" class="space-y-6" data-validate>
        <div class="bg-gray-50 p-4 rounded-lg">
            <div class="grid grid-cols-1 gap-4">
                <div>
                    <label for="credit_id" class="block text-sm font-medium text-gray-700 mb-1">
                        Seleccionar Crédito <span class="text-red-500">*</span>
                    </label>
                    <select id="credit_id" 
                            name="credit_id" 
                            required
                            class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                        <option value="">Seleccione un crédito...</option>
                        <?php foreach ($credits as $credit): ?>
                            <option value="<?php echo $credit['id']; ?>"
                                    data-total="<?php echo $credit['total_amount']; ?>"
                                    data-installments="<?php echo $credit['num_installments']; ?>"
                                    data-balance="<?php echo $credit['outstanding_balance']; ?>"
                                    data-payments="<?php echo $credit['payments_made']; ?>"
                                    <?php echo ($creditId == $credit['id']) ? 'selected' : ''; ?>>
                                <?php 
                                echo htmlspecialchars($credit['customer_name']) . 
                                     " - Saldo: " . formatMoney($credit['outstanding_balance']) .
                                     " (" . $credit['payments_made'] . "/" . $credit['num_installments'] . " cuotas)";
                                ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>

            <div id="creditDetails" class="mt-4 <?php echo $selectedCredit ? '' : 'hidden'; ?>">
                <div class="bg-blue-50 p-4 rounded-lg">
                    <h3 class="text-lg font-medium text-blue-800 mb-2">Detalles del Crédito</h3>
                    <div class="grid grid-cols-2 gap-4 text-sm">
                        <div>
                            <p class="text-blue-600">Monto Total:</p>
                            <p class="font-medium" id="totalAmount">
                                <?php echo $selectedCredit ? formatMoney($selectedCredit['total_amount']) : ''; ?>
                            </p>
                        </div>
                        <div>
                            <p class="text-blue-600">Cuotas Totales:</p>
                            <p class="font-medium" id="totalInstallments">
                                <?php echo $selectedCredit ? $selectedCredit['num_installments'] : ''; ?>
                            </p>
                        </div>
                        <div>
                            <p class="text-blue-600">Saldo Pendiente:</p>
                            <p class="font-medium" id="outstandingBalance">
                                <?php echo $selectedCredit ? formatMoney($selectedCredit['outstanding_balance']) : ''; ?>
                            </p>
                        </div>
                        <div>
                            <p class="text-blue-600">Cuotas Pagadas:</p>
                            <p class="font-medium" id="paidInstallments">
                                <?php echo $selectedCredit ? $selectedCredit['payments_made'] : ''; ?>
                            </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="bg-gray-50 p-4 rounded-lg">
            <h2 class="text-lg font-medium text-gray-800 mb-4">Datos del Pago</h2>
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <label for="payment_amount" class="block text-sm font-medium text-gray-700 mb-1">
                        Monto del Pago <span class="text-red-500">*</span>
                    </label>
                    <div class="relative">
                        <span class="absolute inset-y-0 left-0 pl-3 flex items-center text-gray-500">$</span>
                        <input type="number" 
                               id="payment_amount" 
                               name="payment_amount" 
                               required
                               step="0.01"
                               min="0"
                               value="<?php echo isset($_POST['payment_amount']) ? htmlspecialchars($_POST['payment_amount']) : ''; ?>"
                               class="w-full pl-8 rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                    </div>
                </div>
                <div>
                    <label for="installment_number" class="block text-sm font-medium text-gray-700 mb-1">
                        Número de Cuota <span class="text-red-500">*</span>
                    </label>
                    <input type="number" 
                           id="installment_number" 
                           name="installment_number" 
                           required
                           min="1"
                           value="<?php echo isset($_POST['installment_number']) ? htmlspecialchars($_POST['installment_number']) : ''; ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
                <div>
                    <label for="payment_date" class="block text-sm font-medium text-gray-700 mb-1">
                        Fecha de Pago <span class="text-red-500">*</span>
                    </label>
                    <input type="date" 
                           id="payment_date" 
                           name="payment_date" 
                           required
                           value="<?php echo isset($_POST['payment_date']) ? htmlspecialchars($_POST['payment_date']) : date('Y-m-d'); ?>"
                           class="w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
                </div>
            </div>
        </div>

        <div class="flex justify-end space-x-2">
            <a href="index.php" 
               class="px-4 py-2 border border-gray-300 rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                Cancelar
            </a>
            <button type="submit" 
                    class="px-4 py-2 border border-transparent rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                <i class="fas fa-save mr-1"></i> Registrar Pago
            </button>
        </div>
    </form>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const creditSelect = document.getElementById('credit_id');
    const creditDetails = document.getElementById('creditDetails');
    const totalAmountElement = document.getElementById('totalAmount');
    const totalInstallmentsElement = document.getElementById('totalInstallments');
    const outstandingBalanceElement = document.getElementById('outstandingBalance');
    const paidInstallmentsElement = document.getElementById('paidInstallments');
    const installmentNumberInput = document.getElementById('installment_number');
    const paymentAmountInput = document.getElementById('payment_amount');

    creditSelect.addEventListener('change', function() {
        const selectedOption = this.options[this.selectedIndex];
        
        if (this.value) {
            const total = selectedOption.dataset.total;
            const installments = selectedOption.dataset.installments;
            const balance = selectedOption.dataset.balance;
            const payments = selectedOption.dataset.payments;

            totalAmountElement.textContent = formatMoney(total);
            totalInstallmentsElement.textContent = installments;
            outstandingBalanceElement.textContent = formatMoney(balance);
            paidInstallmentsElement.textContent = payments;
            
            // Sugerir siguiente número de cuota
            installmentNumberInput.value = parseInt(payments) + 1;
            
            // Sugerir monto de cuota
            const suggestedAmount = (total / installments).toFixed(2);
            paymentAmountInput.value = suggestedAmount;
            
            creditDetails.classList.remove('hidden');
        } else {
            creditDetails.classList.add('hidden');
        }
    });

    function formatMoney(amount) {
        return '$ ' + parseFloat(amount).toFixed(2).replace(/\d(?=(\d{3})+\.)/g, '$&,');
    }
});
</script>

<?php 
    require_once 'templates/footer.php';
} catch (Exception $e) {
    error_log("Error en register_payment.php: " . $e->getMessage());
    $errorMessage = "Ha ocurrido un error al procesar la solicitud. Por favor, intente nuevamente.";
    require_once 'templates/header.php';
    echo "<div class='bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4' role='alert'>
            <p class='font-bold'>Error</p>
            <p>$errorMessage</p>
          </div>";
    require_once 'templates/footer.php';
}
?>